==> haskell-regex-compat-0.95.2.1-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-compat
version:              0.95.2.1
visibility:           public
id:                   regex-compat-0.95.2.1-LVT0htu0Mng2BNSRLd0g9E
key:                  regex-compat-0.95.2.1-LVT0htu0Mng2BNSRLd0g9E
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:
    Herbert Valerio Riedel <hvr@gnu.org>,
    Andreas Abel

author:               Christopher Kuklewicz
homepage:             https://wiki.haskell.org/Regular_expressions
synopsis:             Replaces/enhances "Text.Regex"
description:
    One module compat layer over <//hackage.haskell.org/package/regex-posix regex-posix> to replace "Text.Regex".

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  54f5ed1ee1e021b92413c5b21f1d456d
exposed:              True
exposed-modules:      Text.Regex
import-dirs:          /usr/lib/ghc-9.4.8/site-local/regex-compat-0.95.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/regex-compat-0.95.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/regex-compat-0.95.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-compat
hs-libraries:         HSregex-compat-0.95.2.1-LVT0htu0Mng2BNSRLd0g9E
depends:
    array-0.5.4.0 base-4.17.2.1
    regex-base-0.94.0.3-4CB0YhYwj75B1BjBDOnQyh
    regex-posix-0.96.0.2-AHNuIP1Pa8gKU2TxlSaYg9

haddock-interfaces:
    /usr/share/doc/haskell-regex-compat/html/regex-compat.haddock

haddock-html:         /usr/share/doc/haskell-regex-compat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-compat-0.95.2.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-compat
version:              0.95.2.2
visibility:           public
id:                   regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8
key:                  regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:           Andreas Abel
author:               Christopher Kuklewicz
homepage:             https://wiki.haskell.org/Regular_expressions
synopsis:             Replaces/enhances "Text.Regex"
description:
    One module compat layer over <//hackage.haskell.org/package/regex-posix regex-posix> to replace "Text.Regex".

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  ab90b0677602ac3172256ddcd70e8a4b
exposed:              True
exposed-modules:      Text.Regex
import-dirs:          /usr/lib/ghc-9.4.8/site-local/regex-compat-0.95.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/regex-compat-0.95.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/regex-compat-0.95.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-compat
hs-libraries:         HSregex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8
depends:
    array-0.5.4.0 base-4.17.2.1
    regex-base-0.94.0.3-4CB0YhYwj75B1BjBDOnQyh
    regex-posix-0.96.0.2-AHNuIP1Pa8gKU2TxlSaYg9

haddock-interfaces:
    /usr/share/doc/haskell-regex-compat/html/regex-compat.haddock

haddock-html:         /usr/share/doc/haskell-regex-compat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
